# Simulation Tab

The *Simulation* tab contains tools to help you prepare your simulations. Here, you will find four subtabs: *General*, *Domain*, *Data*, and *Run*. In the *General* subtab you can create and open existing GIS4WRF projects. The *Domain*, *Data* and *Run* subtabs contain tools to help you with the steps to define and run a WRF simulation such as defining datasets to use in your simulation, configure namelists and run WPS and WRF programs. Details on how to use these tools and examples are included in the documentation and tutorials section.

## General
Used to create a new, or to open an existing GIS4WRF project. By default a project is created inside the GIS4WRF default working directory.

![General Configuration Tab](../images/tab_simulation_general.png)

## Domains
Used to easily create, import and, export WRF domains through a GUI interface. This configuration will be used to generate the relevant sections in `namelist.wps` and `namelist.wrf`.

![Domain Manager](../images/tab_simulation_domain.png)

### Import/Export
`Import from namelist` button: reads a `namelist.wps` file and populate the fields

`Export to namelist` button: exports domain created to a `namelist.wps` file

### Map Type
`GCS/Projection` dropdown: allows users to define the type Geographical Coordinate System (GCS) or Projection to use for creating the domain. Current supported GCS/Projections are `Latitude/Longitude` and `Lambert`. If Lambert option is selected, the two true latitudes (`True Latitude 1` and `True Latitude 2`) are required.

`Set Map CRS` button: set QGIS Project Coordinate Reference System (CRS) based on selected `GCS/Projection`

### Horizontal Grid Spacing
Domain horizontal grid spacing in decimal degrees (°) for `Latitude/Longitude` or in meters (m) for `Lambert`

### Grid Extent Calculator
`Set to Canvas Extent` allows the user to set the domain center-point `Longitude`, `Latitude`, and the grid extent `Horizontal` and `Vertical` to the QGIS canvas extent. The extent can be modified in `Advanced Configuration` (see next section).

`Set to Active Layer Extent` allows the user to set the domain center-point `Longitude`, `Latitude`, and the grid extent `Horizontal` and `Vertical` to the extent of the active layer in QGIS. The extent can be modified in `Advanced Configuration` (see next section).

### Advanced Configuration
When checked, it enables the user to manually set the center-point latitude and longitude in decimal degrees (°), and the horizontal and vertical gird extent for the inner-most domain.

### Enable Parenting
When checked, it enables the user to create nested-type domains. The number of parent domains can be selected (min:1, max:21). The user must set the `child-to-parent ratio` as well as the padding. The horizontal resolution for the parent domain is calculated automatically based on the resolution of the child domain. **NB:** GIS4WRF calculated nesting opposite to the standard way of creating domains in WRF -- parents domains are created based on the location, extent and resolution of the child domain.


## Data
Used to set datasets to be added in the configuration of namelists.

![Datasets Tab](../images/tab_simulation_data.png)

### Geographical Data
For each domain, the type of geographical data is selected by clicking on the `+` button next to each domain.
Optionally, under `Add Dataset`, a new dataset can be imported to be used in the simulation.This configuration will be used to generate the relevant section in `namelist.wps` and `GEOGRID.TBL`.

### Meteorological Data
The meteorological data is shown under the `Available Dataset` and added by selecting the dataset and time range to be used in the simulation, and clicking on the `Use dataset selection from list` button. This configuration will be used to generate the relevant sections in `namelist.wps` and `namelist.wrf`.

## Run
The run tab is used to run WPS and WRF programs with the the configuration generated by GIS4WRF. Sections of namelists such as physics options can be edited by clicking on the `Open Configuration` button. The output is displayed in the integrated `Program output` window.

![Run Tab](../images/tab_simulation_run.png)